package com.appbackend.aleph.utils;

import com.appbackend.aleph.exception.AlephException;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import org.w3c.dom.Document;
import org.xml.sax.SAXException;

import javax.xml.parsers.ParserConfigurationException;
import java.io.IOException;
import java.time.LocalDateTime;

@Component
public class AlephServiceProcessor {

    @Value("${aleph.url}")
    private String ALEPH_URL;

    @Value("${aleph.and.separator}")
    private String AND_SYMBOL;

    private static String CACHED_SESSION_ID = null;
    private static LocalDateTime SESSION_CACHED_TIME = null;

    public Document processAlephRequest(String request) throws ParserConfigurationException, SAXException, IOException {
        if(SESSION_CACHED_TIME!=null && CACHED_SESSION_ID!=null && DateUtils.getDiffInSeconds(SESSION_CACHED_TIME) < 900) {
            //davam session pokud je alive mene nez 15 minut
            String url = ALEPH_URL + "/X?" + "session_id=" + CACHED_SESSION_ID + AND_SYMBOL + request;
            Document document = XmlUtils.getXmlDocumentFromUrl(url);
            checkXmlResponseForAlephError(document);
            return document;
        } else {
            //kdyz je session id stare tak dam credentials a ulozim session
            String url = ALEPH_URL + "/X?" + "user_name=sic" + AND_SYMBOL + "user_password=bus107" + AND_SYMBOL + request;
            Document document = XmlUtils.getXmlDocumentFromUrl(url);
            checkXmlResponseForAlephError(document);
            SESSION_CACHED_TIME = LocalDateTime.now();
            CACHED_SESSION_ID =  document.getElementsByTagName("session-id").item(0).getTextContent();
            return document;
        }
    }

    private void checkXmlResponseForAlephError(Document document) {
        try {
            String errorMessage = XmlUtils.nodeListToList(document.getElementsByTagName("error")).get(0).getTextContent();
            if(errorMessage!=null) {
                System.out.println("error during call to Aleph X server: " + errorMessage);
                throw new AlephException(errorMessage);
            }
        } catch (IndexOutOfBoundsException e) {
//            "Response from Aleph does not contain error"
        }
    }

}
