package com.appbackend.security.controller;

import com.appbackend.aleph.utils.AlephServiceProcessor;
import com.appbackend.aleph.utils.XmlUtils;
import com.appbackend.security.model.JwtRequest;
import com.appbackend.security.model.JwtResponse;
import com.appbackend.security.utils.JwtTokenUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.ResponseEntity;
import org.springframework.security.authentication.BadCredentialsException;
import org.springframework.web.bind.annotation.*;
import org.w3c.dom.Document;

@RestController
@CrossOrigin
public class JwtAuthenticationController {

    @Value("${aleph.and.separator}")
    private String AND_SYMBOL;

    @Autowired
    private JwtTokenUtil jwtTokenUtil;

    @Autowired
    private AlephServiceProcessor alephServiceProcessor;

    @RequestMapping(value = "/authenticate", method = RequestMethod.POST)
    public ResponseEntity<JwtResponse> authenticate(@RequestBody JwtRequest authenticationRequest) {
        try {
            String request =
                    "op=bor-auth" + AND_SYMBOL +
                    "library=CZU50" + AND_SYMBOL +
                    "bor_id=" + authenticationRequest.getUsername() + AND_SYMBOL +
                    "verification=" + authenticationRequest.getPassword();
            Document document = alephServiceProcessor.processAlephRequest(request);

            String userId = XmlUtils.nodeListToList(document.getElementsByTagName("z303-id")).get(0).getTextContent();
            System.out.println("Logged user: " + authenticationRequest.getUsername() + " with userId:" + userId);
        } catch (Exception e) {
            throw new BadCredentialsException("INVALID_CREDENTIALS", e);
        }

        final String token = jwtTokenUtil.generateToken(authenticationRequest.getUsername());
        return ResponseEntity.ok(new JwtResponse(token));
    }

}
