import React from "react";
import {ActivityIndicator, FlatList, StyleSheet} from "react-native";
import {RobotoBoldText, RobotoText} from "../components/text/StyledText";
import {Button, Card} from "react-native-elements";
import {StyleConstants} from "../style/StyleConstants";
import {MainView} from "../components/view/MainView";
import FeedCard from "../model/FeedCard";
import AlephService from "../services/AlephService";
import * as WebBrowser from 'expo-web-browser';

interface Props  {
}

export const FeedScreen: React.FC<Props> = (props: Props) => {

    const [feedList, setFeedList] = React.useState<FeedCard[]>();
    const [loading, setLoading] = React.useState<boolean>(true);

    const loadFeed = async () => {
        const feed = await AlephService.getFeed();
        setFeedList(feed);
        setLoading(false);
    };

    React.useEffect(() => {
        loadFeed();
    }, []);

    const openInBrowser = async (url: string) => {
        console.log(url);
        await WebBrowser.openBrowserAsync(url);
    };

    const renderItem = ({ item }: { item: FeedCard }) => {
        return (
            <Card
                titleStyle={styles.title}
                containerStyle={styles.container}
                title={item.title}
                image={{uri: item.imgSrc}}
            >
                <RobotoBoldText style={styles.date}>
                    {item.date}
                </RobotoBoldText>
                <RobotoText style={styles.text}>
                    {item.text}
                </RobotoText>
                <Button
                    title='Číst dále'
                    onPress={() => openInBrowser(item.url)}
                    buttonStyle={styles.button}
                  />
            </Card>
        );
    };

    return (
        <MainView>
            {loading && <ActivityIndicator/>}
            {!loading && <FlatList<FeedCard> data={feedList} keyExtractor={item => item.url} renderItem={renderItem}/>}

        </MainView>
    );


};

const styles = StyleSheet.create({
    container: {
        backgroundColor: StyleConstants.BACKGROUND,
        borderColor: StyleConstants.BACKGROUND,
        padding: 0},
    title: {
        color: StyleConstants.PRIMARY_BLUE_COLOR
    },
    date: {
        marginBottom: 4
    },
    text: {
        marginBottom: 10
    },
    button: {
        backgroundColor: StyleConstants.PRIMARY_BLUE_COLOR
    }


});