import React from 'react';
import {ActivityIndicator, FlatList, View} from "react-native";
import CredentialsService from "../services/InternalStoreService";
import User from "../model/User";
import AlephService from "../services/AlephService";
import BookListItem from "../components/BookListItem";
import Constants from "expo-constants";
import CatalogBook from "../model/CatalogBook";

interface Props {
    route: any;
}

interface State {
    history: CatalogBook[],
    loading: boolean
}

export const HistoryScreen: React.FC<Props> = (props: Props) => {

    let userId: string;

    const [state, setState] = React.useState<State>({loading: false, history: props.route.params.history});

    const loadLoans = async () => {
        setState({...state, loading: true});
        let user: User = await CredentialsService.getUser();
        user = await AlephService.getUserInfo(user.username, user.password);
        userId = user.id;
        setState({loading: false, history: user.history});
    };

    const renderItem = ({ item }: { item: CatalogBook }) => (
       <BookListItem title={item.title} author={item.author} year={item.year} isbn={item.isbn}
                      // onPress={() => RootNavigation.navigate('Details', {book: item})}
        >
        </BookListItem>
    );

    return (
      <View style={ {paddingTop: Constants.statusBarHeight}}>
          {state.loading && <ActivityIndicator/>}
          {!state.loading && <FlatList<CatalogBook> data={state.history} renderItem={renderItem} keyExtractor={item => item.isbn}/>}
      </View>
    );


};
