import React from "react";
import {Dimensions, ScrollView, StyleSheet} from "react-native";
import {Divider} from "react-native-elements";
import {MainView} from "../components/view/MainView";
import {RobotoBoldText, RobotoText} from "../components/text/StyledText";
import {StyleConstants} from "../style/StyleConstants";
import MapView from "react-native-maps";


type Props = {}

interface State {

}

export const InfoScreen: React.FC<Props> = () => {


    return (
        <MainView style={{margin: 8}}>
            <ScrollView>
                <RobotoBoldText h3 style={styles.headingStyle}>Typy výpůjček</RobotoBoldText>
                <RobotoText>V knihovně rozlišujeme celkem tři typy výpůjček. Každá z nich má jiný režim. Co zrovna v
                    knihovně nabízíme najdete v našem Katalogu nebo Univerzitním vyhledávači.</RobotoText>

                <RobotoBoldText h4 style={styles.headingStyle}>Absenční výpůjčka</RobotoBoldText>
                <RobotoText>Publikace, jejichž signatura začíná písmenem Z. Jedná se o publikace, kterých máme málo
                    exemplářů a tudíž je nutné urychlit jejich oběh. Proto je půjčujeme v základě jen na 1 měsíc s
                    možností prodloužení až na 3 měsíce.</RobotoText>

                <RobotoBoldText h4 style={styles.headingStyle}>Skripta</RobotoBoldText>
                <RobotoText>Publikace, jejichž signatura začíná písmenem S. Skripta jsou základní studijní literatura, a
                    proto si držíme mnoho výtisků. Tyto publikace půjčujeme v základě na 2 měsíce s možností prodloužení
                    až na 6 měsíců.</RobotoText>

                <RobotoBoldText h4 style={styles.headingStyle}>Prezenční</RobotoBoldText>
                <RobotoText>Publikace, které mají nastavenu i druhou signaturu (většinou začínající písmenem R).
                    Publikace v prezenčním režimu jsou dostupné pro kohokoli, protože se nepůjčují domů. Najdete mezi
                    nimi jak knihy, tak i skripta. K jejich prohlížení navštivte Velkou studovnu.</RobotoText>

                <Divider style={{backgroundColor: StyleConstants.PRIMARY_BLUE_COLOR, height: 4, marginTop: 16}}/>

                <RobotoBoldText h3 style={styles.headingStyle}>Vrácení knih</RobotoBoldText>
                <RobotoText>Knihy můžete vrátit osobně nebo do biblioboxu. Bibliobox vybíráme každý pracovní den dvakrát
                    denně. Máte nemocného kamaráda a chcete vrátit výpůjčky za něj? Není problém, postupujte stejně,
                    jako v případě vracení vlastních knih. Pokud bude mít kamarád pokutu, zaplatí při své příští
                    návštěvě.</RobotoText>

                <RobotoBoldText h3 style={styles.headingStyle}>Bibliobox</RobotoBoldText>
                <RobotoText>Už se vám někdy stalo, že jste chtěli vrátit knihu, ale knihovna byla už zavřená? Tak to už
                    se vám nestane. Před vstupem do budovy se nachází Bibliobox, takže vracet vypůjčené knihy a skripta
                    můžete kdykoli. Výpůjčky vrácené do Biblioboxu po pracovní době načítáme další den, dejte si prosíme
                    pozor na vrácení včas.
                    Pokud máte vypůjčenou větší knihu jako například Genetika, která má 871 stran, tak ji prosíme vraťte
                    přímo do knihovny, aby se v Biblioboxu neponičila. Všechny nadměrné knihy jsou opatřeny informativní
                    samolepkou viz foto.</RobotoText>


                <RobotoBoldText h3 style={styles.headingStyle}>Zpozdné a poplatky</RobotoBoldText>
                <RobotoText>Pokud nevrátíte výpůjčku včas, připravujete další čtenáře o možnost si danou publikaci
                    vypůjčit. Proto máme zaveden systém sankcí, který motivuje uživatele vracet včas, a nebrzdit tak
                    cirkulaci publikací v knihovně.</RobotoText>

                <RobotoBoldText>Pozdě vrácená výpůjčka:</RobotoBoldText>
                <RobotoText>3 Kč/den za každou vypůjčenou publikaci</RobotoText>

                <RobotoBoldText>Nevyzvednutá rezervace:</RobotoBoldText>
                <RobotoText>Jednorázově 10 Kč za každou nevyzvednutou rezervaci</RobotoText>

                <RobotoBoldText>Ztracená publikace:</RobotoBoldText>
                <RobotoText>Dodání stejného titulu nebo jiného za stejnou cenu</RobotoText>

                <Divider style={{backgroundColor: StyleConstants.PRIMARY_BLUE_COLOR, height: 4, marginTop: 16}}/>

                <RobotoBoldText h3 style={styles.headingStyle}>Kontakt</RobotoBoldText>

                <RobotoBoldText>Adresa:</RobotoBoldText>
                <RobotoText>Kamýcká 961/129</RobotoText>
                <RobotoText>165 00 Praha-Suchdol</RobotoText>

                <MapView
                    showsMyLocationButton={true}
                    showsUserLocation={true}
                    showsPointsOfInterest={true}
                    showsCompass={true}
                    toolbarEnabled={true}
                    mapType="hybrid"
                    style={styles.mapStyle} region={{
                    latitude: 50.128877,
                    longitude: 14.372782,
                    latitudeDelta: 0.002,
                    longitudeDelta: 0.002,
                }}>
                </MapView>



            </ScrollView>
        </MainView>
    );
};

const styles = StyleSheet.create({
    container: {
        flex: 1,
        backgroundColor: '#fff',
        alignItems: 'center',
        justifyContent: 'center',
    },
    mapStyle: {
        marginTop: 10,
        marginRight: 8,
        width: Dimensions.get('window').width,
        height: 400,
    },
    headingStyle: {
        color: StyleConstants.PRIMARY_BLUE_COLOR
    }
});